summaryrefslogtreecommitdiff
path: root/ASNMP
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2004-01-17 19:19:21 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2004-01-17 19:19:21 +0000
commit1866657ea123c6556d3c966a09c839e4913a8123 (patch)
tree325e6946065a35bb0518e2d005b8ce135e8b314e /ASNMP
parent33ece395deeb455f61f126819d8a9db86e883e2a (diff)
downloadATCD-1866657ea123c6556d3c966a09c839e4913a8123.tar.gz
ChangeLogTag: Sat Jan 17 19:16:12 UTC 2004 Johnny Willemsen <jwillemsen@remedy.nl>
Diffstat (limited to 'ASNMP')
-rw-r--r--ASNMP/asnmp/ASNMP_Export.h4
-rw-r--r--ASNMP/asnmp/address.h24
-rw-r--r--ASNMP/asnmp/ctr64.cpp8
-rw-r--r--ASNMP/asnmp/ctr64.h8
-rw-r--r--ASNMP/asnmp/octet.h24
-rw-r--r--ASNMP/asnmp/oid.h12
-rw-r--r--ASNMP/asnmp/pdu.h10
-rw-r--r--ASNMP/asnmp/vb.h4
8 files changed, 49 insertions, 45 deletions
diff --git a/ASNMP/asnmp/ASNMP_Export.h b/ASNMP/asnmp/ASNMP_Export.h
index c9ffd580684..e4c9898f3f5 100644
--- a/ASNMP/asnmp/ASNMP_Export.h
+++ b/ASNMP/asnmp/ASNMP_Export.h
@@ -9,6 +9,10 @@
#include "ace/config-all.h"
+#if defined (ACE_AS_STATIC_LIBS) && !defined (ASNMP_HAS_DLL)
+# define ASNMP_HAS_DLL 0
+#endif /* ACE_AS_STATIC_LIBS && ! ASNMP_HAS_DLL */
+
#if !defined (ASNMP_HAS_DLL)
# define ASNMP_HAS_DLL 1
#endif /* ! ASNMP_HAS_DLL */
diff --git a/ASNMP/asnmp/address.h b/ASNMP/asnmp/address.h
index e6d89fedfd0..6a0f9823feb 100644
--- a/ASNMP/asnmp/address.h
+++ b/ASNMP/asnmp/address.h
@@ -110,40 +110,40 @@ public:
virtual ~Address();
// allow destruction of derived classes
- friend int operator==( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator==( const Address &lhs,const Address &rhs);
// overloaded equivlence operator, are two addresses equal?
- friend int operator!=( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator!=( const Address &lhs,const Address &rhs);
// overloaded not equivlence operator, are two addresses not equal?
- friend int operator>( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator>( const Address &lhs,const Address &rhs);
// overloaded > operator, is a1 > a2
- friend int operator>=( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator>=( const Address &lhs,const Address &rhs);
// overloaded >= operator, is a1 >= a2
- friend int operator<( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator<( const Address &lhs,const Address &rhs);
// overloaded < operator, is a1 < a2
- friend int operator<=( const Address &lhs,const Address &rhs);
+ friend ASNMP_Export int operator<=( const Address &lhs,const Address &rhs);
// overloaded <= operator, is a1 <= a2
- friend int operator==( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator==( const Address &lhs,const char *rhs);
// equivlence operator overloaded, are an address and a string equal?
- friend int operator!=( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator!=( const Address &lhs,const char *rhs);
// overloaded not equivlence operator, are an address and string not equal?
- friend int operator>( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator>( const Address &lhs,const char *rhs);
// overloaded < , is an address greater than a string?
- friend int operator>=( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator>=( const Address &lhs,const char *rhs);
// overloaded >=, is an address greater than or equal to a string?
- friend int operator<( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator<( const Address &lhs,const char *rhs);
// overloaded < , is an address less than a string?
- friend int operator<=( const Address &lhs,const char *rhs);
+ friend ASNMP_Export int operator<=( const Address &lhs,const char *rhs);
// overloaded <=, is an address less than or equal to a string?
virtual operator const char *() const = 0;
diff --git a/ASNMP/asnmp/ctr64.cpp b/ASNMP/asnmp/ctr64.cpp
index e11b7cd613b..df3468a1475 100644
--- a/ASNMP/asnmp/ctr64.cpp
+++ b/ASNMP/asnmp/ctr64.cpp
@@ -53,7 +53,7 @@ Counter64::Counter64( unsigned long hiparm, unsigned long loparm)
}
//------------------[ constructor with low value only ]------------------
-Counter64::Counter64( unsigned long long llw )
+Counter64::Counter64( ACE_UINT64 llw )
{
smival.syntax = sNMP_SYNTAX_CNTR64;
smival.value.hNumber.hipart = (unsigned long) (llw >> 32);
@@ -162,7 +162,7 @@ SnmpSyntax& Counter64::operator=( SnmpSyntax &val)
}
// overloaded assignment
-Counter64& Counter64::operator=( const unsigned long long rhs)
+Counter64& Counter64::operator=( const ACE_UINT64 rhs)
{
smival.value.hNumber.hipart = (unsigned long) (rhs >> 32);
smival.value.hNumber.lopart = (unsigned long) rhs;
@@ -178,9 +178,9 @@ Counter64& Counter64::operator=( const Counter64 &rhs)
}
// otherwise, behave like an unsigned long int
-Counter64::operator unsigned long long()
+Counter64::operator ACE_UINT64()
{
- unsigned long long val = smival.value.hNumber.hipart;
+ ACE_UINT64 val = smival.value.hNumber.hipart;
val = val << 32; // shift right 4 bytes
val |= smival.value.hNumber.lopart;
return val;
diff --git a/ASNMP/asnmp/octet.h b/ASNMP/asnmp/octet.h
index 5cd90da0349..7070771ab61 100644
--- a/ASNMP/asnmp/octet.h
+++ b/ASNMP/asnmp/octet.h
@@ -66,40 +66,40 @@ public:
OctetStr& operator=( const OctetStr &octet);
// assignment to another oid object overloaded
- friend int operator==( const OctetStr &lhs, const OctetStr &rhs);
+ friend ASNMP_Export int operator==( const OctetStr &lhs, const OctetStr &rhs);
// equivlence operator overloaded
- friend int operator!=( const OctetStr &lhs, const OctetStr &rhs);
+ friend ASNMP_Export int operator!=( const OctetStr &lhs, const OctetStr &rhs);
// not equivlence operator overloaded
- friend int operator<( const OctetStr &lhs, const OctetStr &rhs);
+ friend ASNMP_Export int operator<( const OctetStr &lhs, const OctetStr &rhs);
// less than < overloaded
- friend int operator<=( const OctetStr &lhs,const OctetStr &rhs);
+ friend ASNMP_Export int operator<=( const OctetStr &lhs,const OctetStr &rhs);
// less than <= overloaded
- friend int operator>( const OctetStr &lhs, const OctetStr &rhs);
+ friend ASNMP_Export int operator>( const OctetStr &lhs, const OctetStr &rhs);
// greater than > overloaded
- friend int operator>=( const OctetStr &lhs, const OctetStr &rhs);
+ friend ASNMP_Export int operator>=( const OctetStr &lhs, const OctetStr &rhs);
// greater than >= overloaded
- friend int operator==( const OctetStr &lhs,const char *rhs);
+ friend ASNMP_Export int operator==( const OctetStr &lhs,const char *rhs);
// equivlence operator overloaded
- friend int operator!=( const OctetStr &lhs,const char *rhs);
+ friend ASNMP_Export int operator!=( const OctetStr &lhs,const char *rhs);
// not equivlence operator overloaded
- friend int operator<( const OctetStr &lhs,const char *rhs);
+ friend ASNMP_Export int operator<( const OctetStr &lhs,const char *rhs);
// less than < operator overloaded
- friend int operator<=( const OctetStr &lhs,char *rhs);
+ friend ASNMP_Export int operator<=( const OctetStr &lhs,char *rhs);
// less than <= operator overloaded
- friend int operator>( const OctetStr &lhs,const char *rhs);
+ friend ASNMP_Export int operator>( const OctetStr &lhs,const char *rhs);
// greater than > operator overloaded
- friend int operator>=( const OctetStr &lhs,const char *rhs);
+ friend ASNMP_Export int operator>=( const OctetStr &lhs,const char *rhs);
// greater than >= operator overloaded
OctetStr& operator+=( const char *a);
diff --git a/ASNMP/asnmp/oid.h b/ASNMP/asnmp/oid.h
index 8ef171317f3..d1f51fd4905 100644
--- a/ASNMP/asnmp/oid.h
+++ b/ASNMP/asnmp/oid.h
@@ -70,22 +70,22 @@ public:
Oid& operator=( const Oid &oid);
// assignment to another oid object overloaded
- friend int operator==( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator==( const Oid &lhs,const Oid &rhs);
// equal operator overloaded
- friend int operator!=( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator!=( const Oid &lhs,const Oid &rhs);
// not equal operator overloaded
- friend int operator<( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator<( const Oid &lhs,const Oid &rhs);
// less than < overloaded
- friend int operator<=( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator<=( const Oid &lhs,const Oid &rhs);
// less than <= overloaded
- friend int operator>( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator>( const Oid &lhs,const Oid &rhs);
// greater than > overloaded
- friend int operator>=( const Oid &lhs,const Oid &rhs);
+ friend ASNMP_Export int operator>=( const Oid &lhs,const Oid &rhs);
// greater than >= overloaded
Oid& operator+=( const char *a);
diff --git a/ASNMP/asnmp/pdu.h b/ASNMP/asnmp/pdu.h
index a031ee84ad9..cf2f3ee8aaf 100644
--- a/ASNMP/asnmp/pdu.h
+++ b/ASNMP/asnmp/pdu.h
@@ -89,19 +89,19 @@ public:
const char *agent_error_reason();
// return the complete error info from this pdu
- friend void set_error_status( Pdu *pdu, const int status);
+ friend ASNMP_Export void set_error_status( Pdu *pdu, const int status);
// set the error status
int get_error_index() const;
// return the error index
- friend void set_error_index( Pdu *pdu, const int index);
+ friend ASNMP_Export void set_error_index( Pdu *pdu, const int index);
// set the error index
- friend void clear_error_status( Pdu *pdu);
+ friend ASNMP_Export void clear_error_status( Pdu *pdu);
// clear error status
- friend void clear_error_index( Pdu *pdu);
+ friend ASNMP_Export void clear_error_index( Pdu *pdu);
// clear error index
unsigned long get_request_id() const;
@@ -187,7 +187,7 @@ public:
};
-class VbIter
+class ASNMP_Export VbIter
// = TITLE
// Utility class to iterate once through a PDU varbind list
{
diff --git a/ASNMP/asnmp/vb.h b/ASNMP/asnmp/vb.h
index 5a2b778748d..a364ec41b11 100644
--- a/ASNMP/asnmp/vb.h
+++ b/ASNMP/asnmp/vb.h
@@ -95,7 +95,7 @@ public:
Vb& operator=( const Vb &vb);
// assignment to another Vb object overloaded
- friend int operator==( const Vb &lhs, const Vb &rhs);
+ friend ASNMP_Export int operator==( const Vb &lhs, const Vb &rhs);
// equivlence operator overloaded
//-----[ set oid / get oid part]------------------------------------------
@@ -172,7 +172,7 @@ public:
// return the current syntax
// Or.. if a V2 VB exception is present then return the exception value
- friend void set_exception_status( Vb *vb, const SmiUINT32 status);
+ friend ASNMP_Export void set_exception_status( Vb *vb, const SmiUINT32 status);
// set the exception status
const char *to_string();
diff --git a/ASNMP/asnmp/ctr64.h b/ASNMP/asnmp/ctr64.h
index 4588db6eb64..bf56851e0f5 100644
--- a/ASNMP/asnmp/ctr64.h
+++ b/ASNMP/asnmp/ctr64.h
@@ -49,7 +49,7 @@ class ASNMP_Export Counter64: public SnmpSyntax
// This class implements RFC 1902 64 bit Counter Object.
{
public:
- Counter64( unsigned long long llw = 0);
+ Counter64( ACE_UINT64 llw = 0);
// default constructor
Counter64( unsigned long hiparm, unsigned long loparm);
@@ -82,7 +82,7 @@ public:
void set_low( const unsigned long l);
// set the low part
- Counter64& operator=( const unsigned long long rhs);
+ Counter64& operator=( const ACE_UINT64 rhs);
// overloaded assignment
Counter64& operator=( const Counter64 &rhs);
@@ -100,8 +100,8 @@ public:
int valid() const;
// general validity test, always true
- operator unsigned long long();
- // otherwise, behave like an unsigned long long
+ operator ACE_UINT64();
+ // otherwise, behave like an ACE_UINT64
protected:
char output_buffer[CTR64OUTBUF];